.. :changelog:

History
-------

0.6.3 2014-12-10
++++++++++++++++

* Expanded PyPI package page.

0.6.2 2014-12-09
++++++++++++++++

* Fixed Sublime Text save workflows.

0.6.1 2014-12-07
++++++++++++++++

* Added Mac Support.

0.5.1 2014-11-13
++++++++++++++++

* Migrated GitHub repository to formwork-io

0.5 2013-10-17
++++++++++++++

* Released to PyPI

0.4 2013-10-17
++++++++++++++

* Fixed crash when multiple changes detected and first triggers restart (`#6`_)

* Fixed default mode always closing FDs (`#5`_)

0.3 2013-10-16
++++++++++++++

* Added ability to specify restart command (`#1`_)

* Added ability to cancel the restart (`#2`_)

0.1 2013-10-15
++++++++++++++

* First functional release.

.. _#6: https://github.com/formwork-io/lazarus/issues/6
.. _#5: https://github.com/formwork-io/lazarus/issues/5
.. _#2: https://github.com/formwork-io/lazarus/issues/2
.. _#1: https://github.com/formwork-io/lazarus/issues/1

